==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/USERFIELD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PROPERTYCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;choice>
 *           &lt;element name="DATEFIELD" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *           &lt;element name="DATETIMEFIELD" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *           &lt;element name="NUMBERFIELD" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *           &lt;element name="TEXTFIELD" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}CODEDESCFIELD" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODEFIELD" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="index" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "propertycode",
    "classid",
    "datefield",
    "datetimefield",
    "numberfield",
    "textfield",
    "codedescfield",
    "entitycodefield"
})
@XmlRootElement(name = "USERFIELD")
public class USERFIELD {

    @XmlElement(name = "PROPERTYCODE", required = true)
    protected String propertycode;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "DATEFIELD")
    protected DATETIME datefield;
    @XmlElement(name = "DATETIMEFIELD")
    protected DATETIME datetimefield;
    @XmlElement(name = "NUMBERFIELD")
    protected QUANTITY numberfield;
    @XmlElement(name = "TEXTFIELD")
    protected String textfield;
    @XmlElement(name = "CODEDESCFIELD")
    protected CODEDESCFIELD codedescfield;
    @XmlElement(name = "ENTITYCODEFIELD")
    protected ENTITYCODEFIELD entitycodefield;
    @XmlAttribute(name = "index")
    protected Long index;

    /**
     * Obtient la valeur de la propriété propertycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYCODE() {
        return propertycode;
    }

    /**
     * Définit la valeur de la propriété propertycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYCODE(String value) {
        this.propertycode = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété datefield.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEFIELD() {
        return datefield;
    }

    /**
     * Définit la valeur de la propriété datefield.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEFIELD(DATETIME value) {
        this.datefield = value;
    }

    /**
     * Obtient la valeur de la propriété datetimefield.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATETIMEFIELD() {
        return datetimefield;
    }

    /**
     * Définit la valeur de la propriété datetimefield.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATETIMEFIELD(DATETIME value) {
        this.datetimefield = value;
    }

    /**
     * Obtient la valeur de la propriété numberfield.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getNUMBERFIELD() {
        return numberfield;
    }

    /**
     * Définit la valeur de la propriété numberfield.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setNUMBERFIELD(QUANTITY value) {
        this.numberfield = value;
    }

    /**
     * Obtient la valeur de la propriété textfield.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTFIELD() {
        return textfield;
    }

    /**
     * Définit la valeur de la propriété textfield.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTFIELD(String value) {
        this.textfield = value;
    }

    /**
     * Obtient la valeur de la propriété codedescfield.
     * 
     * @return
     *     possible object is
     *     {@link CODEDESCFIELD }
     *     
     */
    public CODEDESCFIELD getCODEDESCFIELD() {
        return codedescfield;
    }

    /**
     * Définit la valeur de la propriété codedescfield.
     * 
     * @param value
     *     allowed object is
     *     {@link CODEDESCFIELD }
     *     
     */
    public void setCODEDESCFIELD(CODEDESCFIELD value) {
        this.codedescfield = value;
    }

    /**
     * Obtient la valeur de la propriété entitycodefield.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCODEFIELD }
     *     
     */
    public ENTITYCODEFIELD getENTITYCODEFIELD() {
        return entitycodefield;
    }

    /**
     * Définit la valeur de la propriété entitycodefield.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCODEFIELD }
     *     
     */
    public void setENTITYCODEFIELD(ENTITYCODEFIELD value) {
        this.entitycodefield = value;
    }

    /**
     * Obtient la valeur de la propriété index.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getIndex() {
        return index;
    }

    /**
     * Définit la valeur de la propriété index.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setIndex(Long value) {
        this.index = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/USERFIELD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PROPERTYCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;choice>
 *           &lt;element name="DATEFIELD" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *           &lt;element name="DATETIMEFIELD" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *           &lt;element name="NUMBERFIELD" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *           &lt;element name="TEXTFIELD" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}CODEDESCFIELD" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODEFIELD" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="index" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "propertycode",
    "classid",
    "datefield",
    "datetimefield",
    "numberfield",
    "textfield",
    "codedescfield",
    "entitycodefield"
})
@XmlRootElement(name = "USERFIELD")
public class USERFIELD {

    @XmlElement(name = "PROPERTYCODE", required = true)
    protected String propertycode;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "DATEFIELD")
    protected DATETIME datefield;
    @XmlElement(name = "DATETIMEFIELD")
    protected DATETIME datetimefield;
    @XmlElement(name = "NUMBERFIELD")
    protected QUANTITY numberfield;
    @XmlElement(name = "TEXTFIELD")
    protected String textfield;
    @XmlElement(name = "CODEDESCFIELD")
    protected CODEDESCFIELD codedescfield;
    @XmlElement(name = "ENTITYCODEFIELD")
    protected ENTITYCODEFIELD entitycodefield;
    @XmlAttribute(name = "index")
    protected Long index;

    /**
     * Gets the value of the propertycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTYCODE() {
        return propertycode;
    }

    /**
     * Sets the value of the propertycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTYCODE(String value) {
        this.propertycode = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the datefield property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEFIELD() {
        return datefield;
    }

    /**
     * Sets the value of the datefield property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEFIELD(DATETIME value) {
        this.datefield = value;
    }

    /**
     * Gets the value of the datetimefield property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATETIMEFIELD() {
        return datetimefield;
    }

    /**
     * Sets the value of the datetimefield property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATETIMEFIELD(DATETIME value) {
        this.datetimefield = value;
    }

    /**
     * Gets the value of the numberfield property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getNUMBERFIELD() {
        return numberfield;
    }

    /**
     * Sets the value of the numberfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setNUMBERFIELD(QUANTITY value) {
        this.numberfield = value;
    }

    /**
     * Gets the value of the textfield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTFIELD() {
        return textfield;
    }

    /**
     * Sets the value of the textfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTFIELD(String value) {
        this.textfield = value;
    }

    /**
     * Gets the value of the codedescfield property.
     * 
     * @return
     *     possible object is
     *     {@link CODEDESCFIELD }
     *     
     */
    public CODEDESCFIELD getCODEDESCFIELD() {
        return codedescfield;
    }

    /**
     * Sets the value of the codedescfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link CODEDESCFIELD }
     *     
     */
    public void setCODEDESCFIELD(CODEDESCFIELD value) {
        this.codedescfield = value;
    }

    /**
     * Gets the value of the entitycodefield property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCODEFIELD }
     *     
     */
    public ENTITYCODEFIELD getENTITYCODEFIELD() {
        return entitycodefield;
    }

    /**
     * Sets the value of the entitycodefield property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCODEFIELD }
     *     
     */
    public void setENTITYCODEFIELD(ENTITYCODEFIELD value) {
        this.entitycodefield = value;
    }

    /**
     * Gets the value of the index property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getIndex() {
        return index;
    }

    /**
     * Sets the value of the index property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setIndex(Long value) {
        this.index = value;
    }

}
